@@ -2,24 +2,35 @@
 #
 # Simple perl example to interface with module Search::Circa::Indexer
 # Copyright 2000 A.Barbet alian@alianwebserver.com.  All rights reserved.
-# $Date: 2001/10/28 15:51:11 $
+# $Date: 2001/08/29 17:47:50 $
 #
 
 use strict;
 use Getopt::Long;
 use CircaConf;
-use lib $CircaConf::CircaDir;
+use lib $Circa::CircaDir;
 use Search::Circa::Indexer;
 
-my $indexor = new Search::Circa::Indexer(%CircaConf::conf);
+my $indexor = new Search::Circa::Indexer(
+  'author'              => 'circa@alianwebserver.com', # Responsable du moteur
+  'temporate'           => 0,  # Temporise les requetes sur le serveur de 8s.
+  'facteur_keyword'     => 15, # <meta name="KeyWords"
+  'facteur_description' => 10, # <meta name="description"
+  'facteur_titre'       => 10, # <title></title>
+  'facteur_full_text'   => 1,  # reste
+  'facteur_url'         => 10,
+  'nb_min_mots'         => 2,  # facteur min pour garder un mot
+  'niveau_max'          => 7,  # Niveau max  indexer
+  'indexCgi'            => 0,  # Suit les diffrents liens des CGI 
+					 # (ex: ?nom=toto&riri=eieiei)
+);
 #$indexor->proxy('http://195.154.155.254:3128');
 if ( (@ARGV==0) || ($ARGV[0] eq '-h')) {&usage();}
   
 
-my ($create, $drop, $update, $parse_new, $add, $addSite, $addLocal, $stats,
-    $export, $import, $depth, $drop_id, $debug, $addLocalPrompt, $exportId);
+my ($create,$drop,$update,$parse_new,$add,$addSite,$addLocal,$stats,$export,$import,$depth,$drop_id);
 GetOptions 
-  (
+  (   
    "create"      => \$create,
    "drop"        => \$drop,
    "update=s"    => \$update,
@@ -28,14 +39,11 @@ GetOptions
    "add_site=s"  => \$add,
    "add=s"       => \$addSite,
    "addLocal=s"  => \$addLocal,
-   "addLocalPrompt" => \$addLocalPrompt,
    "stats=s"     => \$stats,
    "export"      => \$export,
-   "exportId=s"  => \$exportId,
    "import"      => \$import,
-   "drop_id=s"   => \$drop_id,
-   "debug=s"     => \$debug);
-$indexor->{DEBUG}=$debug if ($debug);
+   "drop_id=s"   => \$drop_id);
+
 if (!$indexor->connect($CircaConf::User,
 			     $CircaConf::Password,
 			     $CircaConf::Database,
@@ -70,27 +78,6 @@ if ($addLocal)
   $indexor->addLocalSite(@l);
   print "Url $l[0] added\n";
   }
-# Add local site with prompt
-if ($addLocalPrompt)
-  {
-    my @l;
-    push(@l, $indexor->prompt("Url http ?",
-					"http://www.alianwebserver.com/index.html"));
-    push(@l, $indexor->prompt("Email responsable ?",'root@localhost'));
-    push(@l, $indexor->prompt("Titre site ?",'titre de mon site'));
-    push(@l, $indexor->prompt("Url local ?",
-					"file:///usr/local/apache/htdocs/index.html"));
-    my $v = 'file:///usr/local/apache/htdocs/';
-    if ($l[3] =~/^(.*\/)[\w\.]*/) {$v=$1; }
-    push(@l, $indexor->prompt("Url local racine ?", $v));
-    $v = 'http://www.alianwebserver.com/';
-    if ($l[0]=~/^(.*\/)[\w\.]*/) {$v=$1; }
-    push(@l, $indexor->prompt("Url http racine ?",$v));
-    push(@l, $indexor->prompt("Categorie automatique ?",1));
-    my $id = $indexor->addLocalSite(@l);
-    print "Url $l[0] added and account $id created\n";
-  }
-
 
 # Update index
 if ($update) 
@@ -130,9 +117,6 @@ Profondeur $depth : $nbIndexe pages indexes, $nbAjoute pages ajoutes, ".
 # export data
 if ($export) {$indexor->export;}
 
-# export data for one account
-if ($exportId) {$indexor->export(undef,undef,$exportId);}
-
 # import data
 if ($import) {$indexor->import_data;}
 
@@ -176,37 +160,65 @@ sub display
 sub usage
   {
 print <<EOF;
-*******************************************************************************
+******************************************************************
             Circa Indexer version $Search::Circa::Indexer::VERSION
 
-Usage: admin.pl OPTIONS
+Usage: admin.pl [-h] [+create] [+drop] [+export] [+import]
+  [+update=nb_day,id_site] [+stats=id_site]  [+drop_id=id]
+  [+parse_new=id_site] [+add=url, [email], [titre], [masque] ]
+  [+add_site=url [,id] ] 
+  [+addLocal=file,url,email,titre,urlRacine,pathRacine]
 
-OPTIONS are:
+******************************************************************
+EOF
 
-  [+create] Create needed table for Circa
-  [+drop] Drop table for Circa (All Mysql data lost !)
-  [+export] Export all data in circa.sql
-  [+exportId=id] Export data for account id in circa_id.sql
-  [+import] Import data from circa.sql
-  [+drop_id=id] Drop table for account id
+if (@ARGV>0)
+  {
+print <<EOF;
+-------
++create: Create table for Circa
+-------
++drop : Drop table for Circa (All Mysql data lost !)
+-------
++drop_id=id : Drop table for account id
+-------
++export : Export all data in circa.sql
+-------
++import : Import data from circa.sql
+-------
++stats=id : Give some stat about site id
+-------
++parse_new=id [+depth_max]: Parse and indexe url last added for site id
+-------
++add_site=url [,id] : Add url in account id. If no id, 1 is used.
+-------
++update=nb_day,id : Update data for site id last indexed nb_day ago
+  If page aren't updated since last index, page not fetched.
+-------
++add=url, [email], [titre], [template] : Add url to database and
+create a new account.
 
-  [+add=url, [email], [titre], [masque] ] : Create account for url
-  [+add_site=url [,id] ] Add url in account id. If no id, 1 is used.
-  [+addLocalPrompt] : Add a local account (params are asked)
-  [+addLocal=file,url,email,titre,urlRacine,pathRacine,categorieAuto]
+$0 +add=http://www.alianwebserver.com/,
+              alian\@alianwebserver.com,
+              "Alian Web Server",
+              "/home/alian/circa/circa.htm"
+-------
++addLocal=url,email,titre,file,urlRacine,pathRacine :
+Add a local url to database and create a new account.
 
-  [+parse_new=id_account] Parse and indexe url last added for account id
-  [+update=nb_day,id] Update url for account id last indexed nb_day ago
-
-  [+stats=id_account] Give some stat about account id
-  [+debug=(1-4)] Verbose level
-
-*******************************************************************************
+Ex: $0 +addLocal=http://www.alianwebserver.com/index.html,
+           alian\@alianwebserver.com,
+           "Alian Web Server",
+           file:///suse/index.html,
+           file:///suse/,
+           http://www.alianwebserver.com
+-------
 
 If first time you use Circa, you can do:
 $0 +create +add=http://www.monsite.com +parse_new=1 +depth_max
 for index your first url.
 
 EOF
+  }
   exit;
 }
