@@ -2,82 +2,101 @@ package Search::Circa;
 
 # module Circa: provide general method for Circa
 # Copyright 2000 A.Barbet alian@alianwebserver.com.  All rights reserved.
-# $Date: 2003/01/02 12:10:25 $
+
+# $Log: Circa.pm,v $
+# Revision 1.8  2001/08/29 16:18:08  alian
+# - Update POD documentation for new namespace
+#
+# Revision 1.7  2001/08/24 13:37:56  alian
+# - Ajout du prefix Search:: devant chacun des modules
+#
+# Revision 1.6  2001/08/05 20:36:10  alian
+# - Add some doc
+#
+# Revision 1.5  2001/06/02 08:18:26  alian
+# - Add self parameter to appartient method
+#
+# Revision 1.4  2001/05/28 18:41:18  alian
+# - Move Parser method from Circa.pm to Indexer.pm
+#
+# Revision 1.3  2001/05/22 23:28:09  alian
+# - Remove load of Circa::Parser
+# - Add POD Documentation
+#
+# Revision 1.2  2001/05/21 22:51:01  alian
+# - Add field for export and import routine
+# - Add Pod documentation
+#
+# Revision 1.1  2001/05/21 18:47:24  alian
+# - Cumul des fonctions utilises dans l'indexeur et le searcher
+#
+#
 
 use DBI;
 use DBI::DBD;
-use CircaConf;
 use Search::Circa::Categorie;
 use Search::Circa::Url;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-use Carp qw/cluck/;
 
 require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw();
-$VERSION = ('$Revision: 1.18 $ ' =~ /(\d+\.\d+)/)[0];
+$VERSION = ('$Revision: 1.8 $ ' =~ /(\d+\.\d+)/)[0];
 
 #------------------------------------------------------------------------------
 # new
 #------------------------------------------------------------------------------
-sub new  {
-  my $class = shift;
-  my $self = {};
-  bless $self, $class;
-  $self->{DBH} = undef;
-  $self->{PREFIX_TABLE} = 'circa_';
-  $self->{SERVER_PORT}  ="3306";   # Port de mysql par default
-  $self->{DEBUG} = 0;
-  return $self;
-}
-
-sub DESTROY { $_[0]->close(); }
-
+sub new 
+  {
+    my $class = shift;
+    my $self = {};
+    bless $self, $class;
+    $self->{DBH} = undef;
+    $self->{PREFIX_TABLE} = 'circa_';
+    $self->{SERVER_PORT}  ="3306";   # Port de mysql par default
+    #$self->{DEBUG} = 1;
+    return $self;
+  }
 
 #------------------------------------------------------------------------------
 # port_mysql
 #------------------------------------------------------------------------------
-sub port_mysql  {
+sub port_mysql
+  {
   my $self = shift;
   if (@_) {$self->{SERVER_PORT}=shift;}
   return $self->{SERVER_PORT};
-}
+  }
 
 #------------------------------------------------------------------------------
 # pre_tbl
 #------------------------------------------------------------------------------
-sub pre_tbl  {
+sub pre_tbl
+  {
   my $self = shift;
   if (@_) {$self->{PREFIX_TABLE}=shift;}
   return $self->{PREFIX_TABLE};
-}
+  }
 
 #------------------------------------------------------------------------------
 # connect
 #------------------------------------------------------------------------------
-sub connect  {
+sub connect
+  {
   my ($this,$user,$password,$db,$server)=@_;
-  if (!$user and !$password and !$db and !$server) {
-    $user     = $this->{_USER}     || $CircaConf::User;
-    $password = $this->{_PASSWORD} || $CircaConf::Password;
-    $db       = $this->{_DB}       || $CircaConf::Database;
-    $server   = $this->{_HOST}     || $CircaConf::Host;
-  }
-  $server = '127.0.0.1' if (!$server);
   my $driver = "DBI:mysql:database=$db;host=$server;port=".$this->port_mysql;
   $this->{_DB}=$db; $this->{_PASSWORD}=$password; $this->{_USER}=$user;
-  $this->{_HOST}=$server;
   $this->{DBH} = DBI->connect($driver,$user,$password,{ PrintError => 0 }) 
     || return 0;
   return 1;
-}
+  }
 
 #------------------------------------------------------------------------------
 # close
 #------------------------------------------------------------------------------
-sub close {$_[0]->{DBH}->disconnect if ($_[0]->{DBH}); }
+sub close {$_[0]->{DBH}->disconnect;}
 
 #------------------------------------------------------------------------------
 # dbh
@@ -109,22 +128,7 @@ sub start_classic_html
 	  -'dtd'    => '-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd')."\n";
   }
 
-#------------------------------------------------------------------------------
-# trace
-#------------------------------------------------------------------------------
-sub trace  {
-  my ($self, $level, $msg)=@_;
-  cluck if ($level >= 5 and $self->{DEBUG} >= $level);
 
-  if ($self->{DEBUG} >= $level) {
-    $msg= (' 'x(2*$level)).$msg;
-    if ($msg) {
-      if ($ENV{SERVER_NAME}) {
-	print STDERR $msg,"\n"; }
-      else { print $msg,"\n"; }
-    }
-  }
-}
 
 #------------------------------------------------------------------------------
 # header
@@ -156,12 +160,10 @@ sub fetch_first
   {
   my ($self,$requete)=@_;
   my $sth = $self->{DBH}->prepare($requete);
-  my @row;
-  if ($sth->execute) {
-    # Pour chaque categorie
-    @row = $sth->fetchrow_array;
-    $sth->finish;
-  } else { $self->trace(1,"Erreur:$requete:$DBI::errstr<br>"); }
+  $sth->execute || print STDERR "Erreur:$requete:$DBI::errstr<br>";
+  # Pour chaque categorie
+  my @row = $sth->fetchrow_array;
+  $sth->finish;
   if (wantarray()) { return @row; }
   else { return $row[0]; }
   }
@@ -172,29 +174,10 @@ sub fetch_first
 sub appartient
   {
   my ($self,$elem,@liste)=@_;
-  return 0 unless $elem;
   foreach (@liste) {return 1 if ($_ and $_ eq $elem);}
   return 0;
   }
 
-#------------------------------------------------------------------------------
-# prompt
-#------------------------------------------------------------------------------
-sub prompt
-  {
-    my($self,$mess,$def)=@_;
-    my $ISA_TTY = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT)) ;
-    Carp::confess("prompt function called without an argument") 
-	  unless defined $mess;
-    my $dispdef = defined $def ? "[$def] " : " ";
-    $def = defined $def ? $def : "";
-    my $ans;
-    local $|=1;
-    print "$mess $dispdef";
-    if ($ISA_TTY) { chomp($ans = <STDIN>); }
-    else { print "$def\n"; }
-    return ($ans ne '') ? $ans : $def;
-  }
 
 #------------------------------------------------------------------------------
 # POD DOCUMENTATION
@@ -202,7 +185,7 @@ sub prompt
 
 =head1 NAME
 
-Search::Circa - a Search Engine / Indexer running with Mysql
+Circa - a Search Engine/Indexer running with Mysql
 
 =head1 DESCRIPTION
 
@@ -233,132 +216,23 @@ Search::Circa::Search work with Search::Circa::Indexer result.
 Search::Circa::Search is a Perl interface, but it's exist on 
 this package a PHP client too.
 
-Search::Circa is root class for Search::Circa::Indexer and 
-Search::Circa::Search.
-
 =head1 SYNOPSIS
 
 See L<Search::Circa::Search>, L<Search::Circa::Indexer>
 
-=head1 FEATURES
+=head1 SEE ALSO
 
-=over
+L<Search::Circa::Indexer> : Indexer module
 
-=item *
+L<Search::Circa::Search> : Searcher module
 
-Search Features
+L<Search::Circa::Annuaire> : Manage directory of Circa
 
-=over
+L<Search::Circa::Url> : Manage url of Circa
 
-=item *
+L<Search::Circa::Categorie> : Manage categorie of Circa
 
-Boolean query language support : or (default) and ("+") not ("-"). Ex perl + faq -cgi :
-Documents with faq, eventually perl and not cgi.
-
-=item *
-
-Client Perl or PHP
-
-=item *
-
-Can browse site by directory / rubrique.
-
-=item *
-
-Search for different criteria: news, last modified date, language, URL / site.
-
-=back
-
-=item *
-
-Full text indexing
-
-=item *
-
-Different weights for title, keywords, description and rest of page HTML read can be given in configuration
-
-=item *
-
-Herite from features of LWP suite:
-
-=over
-
-=item *
-
-Support protocol HTTP://,FTP://, FILE:// (Can do indexation of filesystem without talk to Web Server)
-
-=item *
-
-Full support of standard robots exclusion (robots.txt). Identification with
-CircaIndexer/0.1, mail alian@alianwebserver.com. Delay requests to
-the same server for 8 secondes. "It's not a bug, it's a feature!" Basic
-rule for HTTP serveur load.
-
-=item *
-
-Support proxy HTTP.
-
-=back
-
-=item *
-
-Make index in MySQL
-
-=item *
-
-Read HTML and full text plain
-
-=item *
-
-Several kinds of indexing : full, incremental, only on a particular server.
-
-=item *
-
-Documents not updated are not reindexed.
-
-=item *
-
-All requests for a file are made first with a head http request, for information
-such as validate, last update, size, etc.Size of documents read can be
-restricted (Ex: don't get all documents > 5 MB). For use with low-bandwidth
-connections, or computers which do not have much memory.
-
-=item *
-
-HTML template can be easily customized for your needs.
-
-=item *
-
-Admin functions available by browser interface or command-line.
-
-=item *
-
-Index the different links found in a CGI (all after name_of_file?)
-
-=back
-
-=head1 FREQUENTLY ASKED QUESTIONS
-
-Q: Where are clients for example ?
-
-A: See in demo directory. For command line, see circa_admin and circa_search,,
-for CGI, take a look in cgi-bin/circa, they are installed with make cgi.
-
-Q: Where are global parameters to connect to Circa ?
-
-A: Use lib/CircaConf.pm file
-
-Q : What is an account for Circa ?
-
-A: It's like a project, or a databse. A namespace for what you want.
-
-Q : How I begin with indexer ?
-
-A: See man page of L<circa_admin>
-
-Q : Did you succed to use Circa with mod_perl ?
-
-A: Yes
+L<Search::Circa::Parser> : Manage Parser of Indexer
 
 =head1 Public interface
 
@@ -367,7 +241,7 @@ Search::Circa::Search object
 
 =over
 
-=item B<connect> I<user, password, database, host>
+=item connect($user, $password, $db, $host)
 
 Connect Circa to MySQL. Return 1 on succes, 0 else
 
@@ -375,89 +249,54 @@ Connect Circa to MySQL. Return 1 on succes, 0 else
 
 =item *
 
-user     : Utilisateur MySQL
+$user     : Utilisateur MySQL
 
 =item *
 
-password : Mot de passe MySQL
+$password : Mot de passe MySQL
 
 =item *
 
-db       : Database MySQL
+$db       : Database MySQL
 
 =item *
 
-bost   : Adr IP du serveur MySQL
+$bost   : Adr IP du serveur MySQL
 
 =back
 
 Connect Circa to MySQL. Return 1 on succes, 0 else
 
-=item B<close>
+=item close
 
-Close connection to MySQL. This method is called with DESTROY method of this
-class.
+Close connection to MySQL
 
-=item B<pre_tbl>
+=item pre_tbl
 
 Get or set the prefix for table name for use Circa with more than one
 time on a same database
 
-=item B<fill_template> I<masque, ref_hash>
+=item fill_template($masque,$vars)
 
-=over
-
-=item *
-
-masque : Path of template
-
-=item *
-
-vars : hash ref with keys/val to substitue
-
-=back
+ $masque : Path of template
+ $vars : hash ref with keys/val to substitue
 
 Give template with remplaced variables
-Ex: 
+Ex: if $$vars{age}=12, and $masque have
 
- $circa->fill_template('A <? $age ?> ans', ('age' => '12 ans'));
+  J'ai <? $age ?> ans,
 
-Will return:
+this function give:
 
   J'ai 12 ans,
 
-=item B<fetch_first> I<request>
+=item fetch_first($requete)
 
 Execute request SQL on db and return first row. In list context, retun full 
 row, else return just first column.
 
-=item B<trace> I<level, msg>
-
-Print message I<msg> on standart output error if debug level for script
-is upper than I<level>.
-
-=item B<prompt> I<message, default_value>
-
-Ask in STDIN for a parameter with message and default_value and return value
-
 =back
 
-=head1 SEE ALSO
-
-L<Search::Circa::Indexer>, Indexer module
-
-L<Search::Circa::Search>, Searcher module
-
-L<Search::Circa::Annuaire>, Manage directory of Circa
-
-L<Search::Circa::Url>, Manage url of Circa
-
-L<Search::Circa::Categorie>, Manage categorie of Circa
-
-=head1 VERSION
-
-$Revision: 1.18 $
-
 =head1 AUTHOR
 
 Alain BARBET alian@alianwebserver.com
