@@ -4,29 +4,53 @@ package Search::Circa::Indexer;
 # Copyright 2000 A.Barbet alian@alianwebserver.com.  All rights reserved.
 
 # $Log: Indexer.pm,v $
-# Revision 1.39  2003/01/02 12:07:48  alian
-# Rewrite set_host_indexed method, update POD doc
+# Revision 1.24  2001/08/29 17:45:32  alian
+# - Correction d'un bug lors de l'affichage d'erreur Mysql dans
+# get_liste_liens
 #
-# Revision 1.38  2002/12/31 09:59:36  alian
-# Update call of look_at to use hash in place of list
+# Revision 1.23  2001/08/29 16:22:06  alian
+# - Remove a & in header_compte
+# - Get down size of url in Get_liste_liens
 #
-# Revision 1.37  2002/12/29 14:35:09  alian
-# Some minor fixe suite to last update
+# Revision 1.22  2001/08/24 13:39:18  alian
+# - Ajout du prefix Search:: devant le nom du module
 #
-# Revision 1.36  2002/12/29 13:55:17  alian
-# Another update of pod documentation
+# Revision 1.21  2001/08/01 19:41:11  alian
+# - Add return code for method connect : now you'll see if Indexer can connect
+# or not
 #
-# Revision 1.35  2002/12/29 03:18:37  alian
-# Update POD documentation
+# Revision 1.20  2001/05/28 18:41:18  alian
+# - Move Parser method from Circa.pm to Indexer.pm
 #
-# Revision 1.34  2002/12/29 00:45:50  alian
-# Don't use last_update with parse_new
+# Revision 1.19  2001/05/23 10:34:01  alian
+# - Remove some close_connect call in export/import method
 #
-# Revision 1.33  2002/12/28 22:25:03  alian
-# Merge addSite / addLocaleSite, use hash for parameters
+# Revision 1.18  2001/05/21 22:47:40  alian
+# - Remove some method use in Search and Indexer and build a father class : Circa.pm
 #
-# Revision 1.32  2002/12/27 12:56:16  alian
-# Add cleandb method
+# Revision 1.17  2001/05/20 12:12:43  alian
+# - Use new URL->update and URL->add signature
+#
+# Revision 1.16  2001/05/15 23:01:14  alian
+# - Use need_parser,  need_update and a_valider
+#
+# Revision 1.15  2001/05/14 23:25:42  alian
+# - Use Circa::Url::non_valide method
+# - Use /usr/bin/ before /usr/local/bin/ in export/import
+#
+# Revision 1.14  2001/05/14 22:14:32  alian
+# - Update POD documentation
+# - Correct bug in update routine
+#
+# Revision 1.13  2001/05/14 18:10:50  alian
+# - Move POD documentation at end of file
+# - Split code into multiple modules : Url, Categorie, Parser
+#
+# Revision 1.12  2001/03/31 19:07:40  alian
+# - Update import and export functions: trouble with parameters,
+# and add some control about file read/write
+# - Update update method: use local url if present
+# - Update set_agent call and usage
 
 use strict;
 use DBI;
@@ -38,41 +62,52 @@ require Exporter;
 
 @ISA = qw(Exporter Search::Circa);
 @EXPORT = qw();
-$VERSION = ('$Revision: 1.39 $ ' =~ /(\d+\.\d+)/)[0];
-
-# Path of mysql binary
-my @path_mysql = qw!/usr/bin /usr/local/bin /opt/bin /opt/local/bin 
-                    /usr/pkg/bin /usr/local/mysql/bin /opt/mysql/bin!;
-push(@path_mysql, split(/:/,$ENV{PATH})) if ($ENV{PATH});
+$VERSION = ('$Revision: 1.24 $ ' =~ /(\d+\.\d+)/)[0];
 
+########## CONFIG  ##########
+my %ConfigMoteurDefault=(
+  'author'    => 'circa@alianwebserver.com', # Responsable du moteur
+  'temporate'     => 1,  # Temporise les requetes sur le serveur de 8s.
+  'facteur_keyword'  => 15, # <meta name="KeyWords"
+  'facteur_description'  => 10, # <meta name="description"
+  'facteur_titre'    => 10, # <title></title>
+  'facteur_full_text'  => 1,  # reste
+  'facteur_url' => 15, # Mots trouvs dans l'url
+  'nb_min_mots'    => 2,  # facteur min pour garder un mot
+  'niveau_max'    => 7,  # Niveau max  indexer
+  'indexCgi'    => 0,  # Suit les diffrents liens des CGI (ex: ?nom=toto&riri=eieiei)
+  );
+########## FIN CONFIG  ##########
 
 #------------------------------------------------------------------------------
 # new
 #------------------------------------------------------------------------------
-sub new  {
-  my $class = shift;
-  my $self = $class->SUPER::new;
-  bless $self, $class;
-  $self->{SIZE_MAX}     = 1000000;  # Size max of file read
-  $self->{HOST_INDEXED} = undef;
-  $self->{PROXY} = undef;
-  $self->{ConfigMoteur} = \%CircaConf::conf;
-  if (@_) {
-    my %vars =@_;
-    while (my($n,$v)= each (%vars)) 
-      {$self->{'ConfigMoteur'}{$n}=$v;}
+sub new 
+  {
+    my $class = shift;
+    my $self = $class->SUPER::new;
+    bless $self, $class;
+    $self->{SIZE_MAX}     = 1000000;  # Size max of file read
+    $self->{HOST_INDEXED} = undef;
+    $self->{PROXY} = undef;
+    $self->{ConfigMoteur} = \%ConfigMoteurDefault;
+    if (@_)
+      {
+	my %vars =@_;
+	while (my($n,$v)= each (%vars)) {$self->{'ConfigMoteur'}->{$n}=$v;}
+      }
+    return $self;
   }
-  return $self;
-}
 
 #------------------------------------------------------------------------------
 #
 #------------------------------------------------------------------------------
-sub connect  {
-  my $self=shift;
-  $self->{PARSER} = Search::Circa::Parser->new($self);
-  return $self->SUPER::connect(@_);
-}
+sub connect 
+  { 
+    my $self=shift;
+    $self->{PARSER} = Search::Circa::Parser->new($self);
+    return $self->SUPER::connect(@_);
+  }
 
 #------------------------------------------------------------------------------
 #
@@ -82,174 +117,162 @@ sub Parser { return $_[0]->{PARSER}; }
 #------------------------------------------------------------------------------
 # size_max
 #------------------------------------------------------------------------------
-sub size_max  {
+sub size_max
+  {
   my $self = shift;
   if (@_) {$self->{SIZE_MAX}=shift;}
   return $self->{SIZE_MAX};
-}
-
-#------------------------------------------------------------------------------
-# cleandb
-#------------------------------------------------------------------------------
-sub cleandb  {
-  my $self = shift;
-  my $id = shift;
-  my $r = 1;
-  my ($x) = ($self->fetch_first
-    ("select count(*) from ".$self->pre_tbl.$id."links ".
-     "where parse='1' and valide ='1'"))/2;
-  if ($x !=0) {
-    my $requete = "select mot,count(1) from ".
-    $self->pre_tbl.$id."relation r group by r.mot order by 2 desc limit 200";
-    my $sth = $self->{DBH}->prepare($requete);
-    $sth->execute;
-    while (my ($word,$nb)=$sth->fetchrow_array) {
-      $self->{DBH}->do("delete from ".$self->pre_tbl.$id."relation ".
-		       "where mot = '$word'") if ($nb>$x);
-    }
-    $sth->finish;
-    return $r;
-  } else { return 0;}
-}
+  }
 
 #------------------------------------------------------------------------------
 # host_indexed
 #------------------------------------------------------------------------------
-sub host_indexed  {
+sub host_indexed
+  {
   my $self = shift;
   if (@_) {$self->{HOST_INDEXED}=shift;}
   return $self->{HOST_INDEXED};
-}
+  }
 
 #------------------------------------------------------------------------------
 # set_host_indexed
 #------------------------------------------------------------------------------
-sub set_host_indexed {
+sub set_host_indexed
+  {
   my $this=shift;
   my $url=$_[0];
-  $this->trace(3, "Circa::Indexer::set_host_indexed $url");
-  if ($url=~m!^(http://[^/]*)!) {$this->host_indexed($1);}
-  elsif ($url=~m!^(http://[^/]*)!) {$this->host_indexed($1);}
-  elsif ($url=~m!^(file:///[^/]*)!) {$this->host_indexed($1);}
+  if ($url=~/^(http:\/\/.*?)\/$/) {$this->host_indexed($1);}
+  elsif ($url=~/^(http:\/\/.*?)\/[^\/]+$/) {$this->host_indexed($1);}
+  elsif ($url=~/^(file:\/\/\/[^\/]*)\//) {$this->host_indexed($1);}
   else {$this->host_indexed($url);}
-}
+  }
 
 #------------------------------------------------------------------------------
 # proxy
 #------------------------------------------------------------------------------
-sub proxy  {
+sub proxy
+  {
   my $self = shift;
   if (@_) {$self->{PROXY}=shift;}
   return $self->{PROXY};
-}
+  }
 
 #------------------------------------------------------------------------------
 # addSite
 #------------------------------------------------------------------------------
-sub addSite  {
-  my ($self,$rc)=@_;
-  #print "$url,$email,$titre,$categorieAuto,$cgi,$rep,$file\n";
-  my $file = $rc->{masque} || ' ';
-  if ($rc->{cgi} and $rc->{cgi}->param('file')) {
-    $file=$rc->{cgi}->param('file');
-    my $tmpfile=$rc->{cgi}->tmpFileName($file); # chemin du fichier temp
-    if ($file=~/.*\\(.*)$/) {$file=$1;}
-    $file = $CircaConf::TemplateDir.$file;
-    use File::Copy;
-    copy($tmpfile,$file)
-      or die "Impossible de creer $file avec $tmpfile:$!\n<br>";
-  }
-  if (!$rc->{email}) {$rc->{email}='Inconnu';}
-  if (!$rc->{titre}) {$rc->{titre}='Non fourni';}
-  if (!$rc->{categorieAuto}) {$rc->{categorieAuto}=0;}
-
-  my $requete = "
-insert into ".$self->pre_tbl."responsable (email,titre,categorieAuto,masque)
-values ('$rc->{email}',
-        '$rc->{titre}',
-        '$rc->{categorieAuto}',
-        '$file')";
-  my $sth = $self->{DBH}->prepare($requete);
-  $sth->execute || $self->trace(3, $DBI::errstr.$requete);
+sub addSite
+  {
+    my ($self,$url,$email,$titre,$categorieAuto,$cgi,$rep,$file)=@_;
+    #print "$url,$email,$titre,$categorieAuto,$cgi,$rep,$file\n";
+    if ($cgi)
+      {
+	$file=$cgi->param('file');
+	my $tmpfile=$cgi->tmpFileName($file); # chemin du fichier temp
+	if ($file=~/.*\\(.*)$/) {$file=$1;}
+	my $fileC=$file;
+	$file = $rep.$file;
+	use File::Copy;
+	copy($tmpfile,$file) 
+	  || die "Impossible de creer $file avec $tmpfile:$!\n<br>";
+      }
+    if (!$email) {$email='Inconnu';}
+    if (!$titre) {$titre='Non fourni';}
+    if (!$file) {$file=' ';}
+    if (!$categorieAuto) {$categorieAuto=0;}
+    my $sth = $self->{DBH}->prepare("
+         insert into ".$self->pre_tbl."responsable
+                   (email,titre,categorieAuto,masque) 
+         values ('$email','$titre',$categorieAuto,'$file')");
+  $sth->execute || print "Erreur: $DBI::errstr<br>\n";
   $sth->finish;
-  my $id = $sth->{'mysql_insertid'};
-  $self->create_table_circa_id($id);
-  my %h = (url => $rc->{url}, valide =>1);
-
-  # Site avec double url
-  # Params orig, dest
-  if ($rc->{orig}) {
-    $h{urllocal} = $rc->{url};
-    $h{urllocal}=~s/$rc->{dest}/$rc->{orig}/;
-    my $requete = "insert into ".$self->pre_tbl."local_url
-                   values($id,'$rc->{orig}','$rc->{dest}')";
-    $self->trace(3, $requete);
-    $self->{DBH}->do($requete);
+  $self->create_table_circa_id($sth->{'mysql_insertid'});
+  $self->URL->add($sth->{'mysql_insertid'},(url => $url, valide =>1))
+    || print $DBI::errstr,"\n";
+  return $sth->{'mysql_insertid'};
   }
 
-  $self->URL->add($id,%h);
-  return $id;
-}
+#------------------------------------------------------------------------------
+# addLocalSite
+#------------------------------------------------------------------------------
+sub addLocalSite
+  {
+    my ($self,$url,$email,$titre,$local_url,$path,$urlRacine,
+	$categorieAuto,$cgi,$rep,$file)=@_;
+    if ($cgi)
+      {
+	$file=$cgi->param('file');
+	my $tmpfile=$cgi->tmpFileName($file); # chemin du fichier temp
+	if ($file=~/.*\\(.*)$/) {$file=$1;}
+	my $fileC=$file;
+	$file = $rep.$file;
+	use File::Copy;
+	copy($tmpfile,$file) 
+	  || die "Impossible de creer $file avec $tmpfile:$!\n<br>";
+      }
+    my $sth = $self->{DBH}->prepare("
+              insert into ".$self->pre_tbl."responsable
+                  (email,titre,categorieAuto) 
+              values('$email','$titre',$categorieAuto)");
+    $sth->execute;
+    $sth->finish;
+    my $id = $sth->{'mysql_insertid'};
+    $self->{DBH}->do("insert into ".$self->pre_tbl."local_url 
+                      values($id,'$urlRacine','$path');");
+    $self->create_table_circa_id($sth->{'mysql_insertid'});
+  $self->URL->add($id,(url=> $url, local_url => $local_url, valide=>1)) 
+    || print "Erreur: $DBI::errstr<br>\n";
+  }
 
 #------------------------------------------------------------------------------
 # parse_new_url
 #------------------------------------------------------------------------------
-sub parse_new_url  {
-  my ($self,$idp)=@_; 
-  print "Indexer::parse_new_url\n" if ($self->{DEBUG});
-  my ($nb,$nbAjout,$nbWords,$nbWordsGood)=(0,0,0,0);
-  my $tab = $self->URL->need_parser($idp);
-  my $categorieAuto = $self->categorie->auto($idp);
-  $self->Parser->{toindex} = scalar keys %{$tab};
-  $self->Parser->{inindex} =  0;
-
-  foreach my $id (keys %$tab) {
-    $self->Parser->{inindex}++;
-    my ($url,$local_url,$niveau,$categorie,$lu)=$$tab{$id};
-    my ($res,$nbw,$nbwg) =
-      $self->Parser->look_at({ url           => $$tab{$id}[0],
-			       idc           => $id,
-			       idr           => $idp,
-			       url_local     => $$tab{$id}[1] || undef,
-			       categorieAuto => $categorieAuto,
-			       niveau        => $$tab{$id}[2],
-			       categorie     => $$tab{$id}[3]});
-    if ($res==-1) {$self->URL->non_valide($idp,$id);}
-    else {$nbAjout+=$res;$nbWords+=$nbw;$nb++;$nbWordsGood+=$nbwg;}
+sub parse_new_url
+  {
+    my ($self,$idp)=@_; 
+    print "Indexer::parse_new_url\n" if ($self->{DEBUG});
+    my ($nb,$nbAjout,$nbWords,$nbWordsGood)=(0,0,0,0);
+    my $tab = $self->URL->need_parser($idp);
+    my $categorieAuto = $self->categorie->auto($idp);
+    foreach my $id (keys %$tab) 
+      {
+	my ($url,$local_url,$niveau,$categorie,$lu)=$$tab{$id};
+	my ($res,$nbw,$nbwg) = 
+	  $self->Parser->look_at
+	    (
+	     $$tab{$id}[0],$id,$idp,				 
+	     ($$tab{$id}[4]||undef), 
+	     ($$tab{$id}[1]||undef),				 
+	     $categorieAuto, $$tab{$id}[2], $$tab{$id}[3]);
+	if ($res==-1) {$self->URL->non_valide($idp,$id);}
+	else {$nbAjout+=$res;$nbWords+=$nbw;$nb++;$nbWordsGood+=$nbwg;}
+      }  
+    return ($nb,$nbAjout,$nbWords,$nbWordsGood);
   }
-  return ($nb,$nbAjout,$nbWords,$nbWordsGood);
-}
 
 
 #------------------------------------------------------------------------------
 # update
 #------------------------------------------------------------------------------
-sub update {
-  my ($this,$xj,$idp)=@_;
-  $idp = 1 if (!$idp);
-  $this->parse_new_url($idp);
-  my ($nb,$nbAjout,$nbWords,$nbWordsGood)=(0,0,0,0);
-  my $tab = $this->URL->need_update($idp,$xj);
-  my $categorieAuto = $this->categorie->auto($idp);
-  $this->Parser->{toindex} = scalar keys %{$tab};
-  $this->Parser->{inindex} =  0;
-  foreach my $id (keys %$tab) {
-    $this->Parser->{inindex}++;
-    my ($url,$local_url,$niveau,$categorie,$lu) = $$tab{$id};
-    my ($res,$nbw,$nbwg) = 
-      $this->Parser->look_at( { url           => $$tab{$id}[0],
-				idc           => $id,
-				idr           => $idp,
-				lastModif     => $$tab{$id}[4] || undef,
-				url_local     => $$tab{$id}[1] ||undef,
-				categorieAuto => $categorieAuto,
-				niveau        => $$tab{$id}[2],
-				categorie     => $$tab{$id}[3]});
-    if ($res==-1) {$this->URL->non_valide($idp,$id);}
-    else {$nbAjout+=$res;$nbWords+=$nbw;$nb++;$nbWordsGood+=$nbwg;}
+sub update
+  {
+    my ($this,$xj,$idp)=@_;
+    $idp = 1 if (!$idp);
+    $this->parse_new_url($idp);  
+    my ($nb,$nbAjout,$nbWords,$nbWordsGood)=(0,0,0,0);
+    my $tab = $this->URL->need_update($idp,$xj);
+    my $categorieAuto = $this->categorie->auto($idp);
+    foreach my $id (keys %$tab) 
+      {
+	my ($url,$local_url,$niveau,$categorie,$lu) = $$tab{$id};
+	my ($res,$nbw,$nbwg) = 
+	  $this->Parser->look_at($$tab{$id}[0],$id,$idp,
+				 $$tab{$id}[4] || undef, $$tab{$id}[1] ||undef,
+				 $categorieAuto, $$tab{$id}[2], $$tab{$id}[3]);
+	if ($res==-1) {$this->URL->non_valide($idp,$id);}
+	else {$nbAjout+=$res;$nbWords+=$nbw;$nb++;$nbWordsGood+=$nbwg;}
+      }
+    return ($nb,$nbAjout,$nbWords,$nbWordsGood);
   }
-  return ($nb,$nbAjout,$nbWords,$nbWordsGood);
-}
 
 #------------------------------------------------------------------------------
 # create_table_circa
@@ -257,7 +280,6 @@ sub update {
 sub create_table_circa
   {
   my $self = shift;
-  my $r = 1;
   my $requete="
 CREATE TABLE ".$self->pre_tbl."responsable (
    id     int(11) DEFAULT '0' NOT NULL auto_increment,
@@ -268,7 +290,7 @@ CREATE TABLE ".$self->pre_tbl."responsable (
    PRIMARY KEY (id)
 )";
 
-  $self->{DBH}->do($requete) || ($r = 0 && print $DBI::errstr,"<br>\n");
+  $self->{DBH}->do($requete) || print $DBI::errstr,"<br>\n";
   $requete="
 CREATE TABLE ".$self->pre_tbl."inscription (
    email  char(25) NOT NULL,
@@ -276,7 +298,7 @@ CREATE TABLE ".$self->pre_tbl."inscription (
    titre  char(50) NOT NULL,
    dateins  date
 )";
-  $self->{DBH}->do($requete) || ($r = 0 && print $DBI::errstr,"<br>\n");
+  $self->{DBH}->do($requete) || print $DBI::errstr,"<br>\n";
 
   $requete="
 CREATE TABLE ".$self->pre_tbl."local_url (
@@ -284,30 +306,27 @@ CREATE TABLE ".$self->pre_tbl."local_url (
    path  varchar(255) NOT NULL,
    url  varchar(255) NOT NULL
 )";
-  $self->{DBH}->do($requete) || ($r = 0 && print $DBI::errstr,"<br>\n");
-  return $r;
-}
+  $self->{DBH}->do($requete) || print $DBI::errstr,"<br>\n";
+  }
 
 #------------------------------------------------------------------------------
 # drop_table_circa
 #------------------------------------------------------------------------------
-sub drop_table_circa {
+sub drop_table_circa
+  {
   my $self = shift;
   my $sth = $self->{DBH}->prepare
     ("select id from ".$self->pre_tbl."responsable");
-  if ($sth->execute()) {
-    while (my @row=$sth->fetchrow_array) {
-      $self->drop_table_circa_id($row[0]) if ($row[0]);
-    }
-    $sth->finish;
-    $self->{DBH}->do("drop table ".$self->pre_tbl."responsable")
-      || print $DBI::errstr,"<br>\n";
-    $self->{DBH}->do("drop table ".$self->pre_tbl."inscription")
-      || print $DBI::errstr,"<br>\n";
-    $self->{DBH}->do("drop table ".$self->pre_tbl."local_url")
-      || print $DBI::errstr,"<br>\n";
-  } else { $self->trace(1,"drop_table_circa $DBI::errstr\n"); }
-}
+  $sth->execute() || print $self->header,$DBI::errstr,"<br>\n";
+  while (my @row=$sth->fetchrow_array) {$self->drop_table_circa_id($row[0]);}
+  $sth->finish;
+  $self->{DBH}->do("drop table ".$self->pre_tbl."responsable")
+    || print $DBI::errstr,"<br>\n";
+  $self->{DBH}->do("drop table ".$self->pre_tbl."inscription") 
+    || print $DBI::errstr,"<br>\n";
+  $self->{DBH}->do("drop table ".$self->pre_tbl."local_url")  
+    || print $DBI::errstr,"<br>\n";
+  }
 
 #------------------------------------------------------------------------------
 # drop_table_circa_id
@@ -316,21 +335,16 @@ sub drop_table_circa_id
   {
   my $self = shift;
   my $id=$_[0];
-  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."categorie")
-    || return 0;
-  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."links")
-    || return 0;
-  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."relation")
-    || return 0;
-  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."stats")
-    || return 0;
- $self->{DBH}->do
-    ("delete from ".$self->pre_tbl."local_url where id=$id")
-    || return 0;
+  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."categorie")  
+    || print $DBI::errstr,"<br>\n";
+  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."links")      
+    || print $DBI::errstr,"<br>\n";
+  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."relation")   
+    || print $DBI::errstr,"<br>\n";
+  $self->{DBH}->do("drop table ".$self->pre_tbl.$id."stats")      
+    || print $DBI::errstr,"<br>\n";
   $self->{DBH}->do
-    ("delete from ".$self->pre_tbl."responsable where id=$id")
-    || return 0;
-  return 1;
+    ("delete from ".$self->pre_tbl."responsable where id=$id");
   }
 
 #------------------------------------------------------------------------------
@@ -396,76 +410,42 @@ CREATE TABLE ".$self->pre_tbl.$id."stats (
 #------------------------------------------------------------------------------
 # export
 #------------------------------------------------------------------------------
-sub export  {
-  my ($self,$dump,$path,$id)=@_;
-  my ($pass, $file, $host, $user);
-  if (!$path) { $path=$CircaConf::export; }
-  if (!$path) { $path="/tmp"; }
-  $file=$path."/circa";
-  $file.=$id unless !$id;
-  $file.=".sql";
-  $file=~s/\/\//\//g;
-
-  if ( (! -w $path) || ( ( -e $file) && (!-w $file)))  
-    {$self->close; die "Can't create $file (not enough rights ?):$!\n";}
-  if ( (!$dump) || (! -x $dump)) {
-    foreach (@path_mysql) {
-      if (-x $_."/mysqldump") {$dump = "$_/mysqldump" ; last; }
+sub export
+  {
+  my ($self,$dump,$path)=@_;
+  my ($pass,$file);
+  if (!$path) {use Cwd;$path=cwd;}
+  $file=$path."/circa.sql";$file=~s/\/\//\//g;
+  if ( (! -w $path) || ( ( -e $file) && (!-w $file)))  {$self->close; die "Can't create $file:$!\n";}
+  if ( (!$dump) || (! -x $dump))
+    {
+    if (-x "/usr/bin/mysqldump") {$dump = "/usr/bin/mysqldump" ;}
+    elsif (-x "/usr/local/bin/mysqldump"){$dump = "/usr/local/bin/mysqldump";}
+    elsif (-x "/opt/bin/mysqldump") {$dump = "/opt/bin/mysqldump" ;}
+    else {$self->close; die "Can't find mysqldump.\n";}
     }
-  }
-  if ( (!$dump) || (! -x $dump)) {
-    $self->close; die "Can't find mysqldump.\n";
-  }
-  if ((-e $file) && (!(unlink $file)))
-	{ $self->close; die "Can't unlink $file:$!\n";}
-
+  unlink $file;
   my (@t,@exec);
-
-  if (!$id) {
-    my $requete = "select id from ".$self->pre_tbl."responsable";
-    $requete.= " where id = $id" unless (!$id);
-    my $sth = $self->{DBH}->prepare($requete);
-    $sth->execute;
-    while (my ($id)=$sth->fetchrow_array) {push(@t,$id);}
-    $sth->finish;
-  }
-  else { push(@t,$id); }
-
+  my $requete = "select id from ".$self->pre_tbl."responsable";
+  my $sth = $self->{DBH}->prepare($requete);
+  $sth->execute;
+  while (my ($id)=$sth->fetchrow_array) {push(@t,$id);}
+  $sth->finish;
   if ($self->{_PASSWORD}) {$pass=" -p".$self->{_PASSWORD}.' ';}
   else {$pass=' ';}
-
-  if ($self->{_HOST}) {$host=" -h".$self->{_HOST}.' ';}
-  else {$host=' ';}
-  my $option = " -u".$self->{_USER}.
-    $pass.$host.$self->{_DB}." ".$self->pre_tbl;
-  if (!$id)
-    {
-	$option=" --add-drop-table ".$option;
-	push(@exec,$dump.$option."responsable >> $file");
-	push(@exec,$dump.$option."local_url   >> $file");
-	push(@exec,$dump.$option."inscription >> $file");
-    }
-  else { $option=" --no-create-info ".$option; }
-
+  push(@exec,$dump." --add-drop-table -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl."responsable >> $file");
+  push(@exec,$dump." --add-drop-table  -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl."local_url >> $file");
+  push(@exec,$dump." --add-drop-table  -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl."inscription >> $file");
   foreach my $id (@t)
     {
-	my $opt = $option.$id;
-	my $p = $self->pre_tbl.$id;
-	push(@exec,"echo 'DELETE FROM ".$p."categorie;'>> $file");
-	push(@exec,$dump.$opt."categorie  >> $file");
-	push(@exec,"echo 'DELETE FROM ".$p."links;'>> $file");
-	push(@exec,$dump.$opt."links      >> $file");
-	push(@exec,"echo 'DELETE FROM ".$p."relation;'>> $file");
-	push(@exec,$dump.$opt."relation   >> $file");
+    push(@exec,$dump." --add-drop-table -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl.$id."categorie >> $file");
+    push(@exec,$dump." --add-drop-table -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl.$id."links >> $file");
+    push(@exec,$dump." --add-drop-table -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl.$id."relation >> $file");
+    #push(@exec,$dump." --add-drop-table -u".$self->{_USER}.$pass.$self->{_DB}." ".$self->pre_tbl.$id."stats >> $file");
     }
   $|=1;
   print "En cours d'export ...";
-  $self->trace(2," ");
-  foreach (@exec) 
-    {
-	$self->trace(2,"\t$_");
-	system($_) ==0 or print "Fail:$?-$!\n";
-    }
+  foreach (@exec) {system($_) ==0 or print "Fail:$?-$!\n";}
   print "$file done.\n";
   }
 
@@ -477,23 +457,20 @@ sub import_data
   {
   my ($self,$dump,$path)=@_;
   my ($pass,$file);
-  if (!$path) { $path=$CircaConf::export; }
-  if (!$path) { $path="/tmp"; }
+  if (!$path) {use Cwd;$path=cwd;}
   $file=$path."/circa.sql";$file=~s/\/\//\//g;
   if (! -r $file) {$self->close; die "Can't find $file:$!\n";}
-  if ( (!$dump) || (! -x $dump)) {
-    foreach (@path_mysql) {
-      if (-x $_."/mysql") {$dump = "$_/mysql" ; last; }
+  if ( (!$dump) || (! -x $dump))
+    {
+    if (-x "/usr/bin/mysql") {$dump = "/usr/bin/mysql" ;}
+    elsif (-x "/usr/local/bin/mysql") {$dump = "/usr/local/bin/mysql" ;}
+    elsif (-x "/opt/bin/mysql") {$dump = "/opt/bin/mysql" ;}
+    else {$self->disconnect; die "Can't find mysql.\n";}
     }
-  }
-  if ( (!$dump) || (! -x $dump)) {
-    $self->close; die "Can't find mysql.\n";
-  }
   $|=1;
   print "En cours d'import ...";
   my $c = $dump." -u".$self->{_USER};
-  $c.=" -p".$self->{_PASSWORD}." " if ($self->{_PASSWORD});
-  $c.=" -h".$self->{_HOST}." " if ($self->{_HOST});
+  $c.=" -p".$self->{_PASSWORD} if ($self->{_PASSWORD});
   $c.=" ".$self->{_DB}." < ".$file;
   system($c) == 0 or print "Fail:$c:$?\n";
   print "$file imported.\n";
@@ -514,10 +491,8 @@ sub admin_compte
   if (!$rep{'responsable'}) {return (undef);}
   # First url added
   ($rep{'racine'})=$self->fetch_first("select min(id) from ".$pre."links");
-  if ($rep{'racine'}) {
-    ($rep{'racine'})=$self->fetch_first("select url from ".$pre."links ".
+  ($rep{'racine'})=$self->fetch_first("select url from ".$pre."links ".
 				  "where id=".$rep{'racine'});
-  }
   # Number of links
   ($rep{'nb_links'}) = $self->fetch_first("select count(1) from ".$pre."links");
   # Number of parsed links
@@ -539,9 +514,6 @@ sub admin_compte
   # Number of word
   ($rep{"nb_words"}) = 
     $self->fetch_first("select count(1) from ".$pre."relation");
-  ($rep{"orig"},$rep{"dest"}) = 
-    $self->fetch_first("select path, url from ".$self->pre_tbl."local_url ".
-		       "where id = $compte");
   # Return reference of hash
   return \%rep;
   }
@@ -663,25 +635,20 @@ sub get_liste_liens_a_valider
 #------------------------------------------------------------------------------
 # get_liste_site
 #------------------------------------------------------------------------------
-sub get_liste_site  {
+sub get_liste_site
+  {
   my ($self,$cgi)=@_;
   my %tab;
-  my $sth = $self->{DBH}->prepare("select id,email,titre from ".
-				  $self->pre_tbl."responsable");
-  if ($sth->execute()) {
-    while (my @row=$sth->fetchrow_array) {$tab{$row[0]}="$row[1]/$row[2]";}
-    $sth->finish;
-    my @l =sort { $tab{$a} cmp $tab{$b} } keys %tab;
-    return $cgi->scrolling_list(  -'name'=>'id',
-				  -'values'=>\@l,
-				  -'size'=>1,
-				  -'labels'=>\%tab);
-  }
-  else {
-    $self->trace(1,"Circa::Indexer->get_liste_site $DBI::errstr\n");
-    return undef;
-  }
-}
+  my $sth = $self->{DBH}->prepare("select id,email,titre from ".$self->pre_tbl."responsable");
+  $sth->execute() || print $self->header,$DBI::errstr,"<br>\n";
+  while (my @row=$sth->fetchrow_array) {$tab{$row[0]}="$row[1]/$row[2]";}
+  $sth->finish;
+  my @l =sort { $tab{$a} cmp $tab{$b} } keys %tab;
+  return $cgi->scrolling_list(  -'name'=>'id',
+                             -'values'=>\@l,
+                             -'size'=>1,
+                             -'labels'=>\%tab);
+        }
 
 #------------------------------------------------------------------------------
 # get_liste_mot
@@ -750,27 +717,27 @@ a www search engine running with Mysql
 
  use Circa::Indexer;
  my $indexor = new Circa::Indexer;
- 
- die "Erreur  la connection MySQL:$DBI::errstr\n"
-   if (!$indexor->connect);
- 
+
+ if (!$indexor->connect_mysql($user,$pass,$db))
+  {die "Erreur  la connection MySQL:$DBI::errstr\n";}
+
  $indexor->create_table_circa;
- 
+
  $indexor->drop_table_circa;
- 
- $indexor->addSite({url   => "http://www.alianwebserver.com/",
-                    email => 'alian@alianwebserver.com',
-                    title => "Alian Web Server"});
- 
+
+ $indexor->addSite("http://www.alianwebserver.com/",
+                   'alian@alianwebserver.com',
+                   "Alian Web Server");
+
  my ($nbIndexe,$nbAjoute,$nbWords,$nbWordsGood) = $indexor->parse_new_url(1);
  print   "$nbIndexe pages indexes,"
    "$nbAjoute pages ajoutes,"
    "$nbWordsGood mots indexs,"
    "$nbWords mots lus\n";
- 
+
  $indexor->update(30,1);
 
-Look too in L<circa_admin>,admin.cgi,admin_compte.cgi
+Look in admin.pl,admin.cgi,admin_compte.cgi
 
 =head1 DESCRIPTION
 
@@ -818,6 +785,105 @@ Weight for each word is in hash $ConfigMoteur
 
 =back
 
+=head2 Features ?
+
+Features
+
+=over
+
+=item *
+
+Search Features
+
+=over
+
+=item *
+
+Boolean query language support : or (default) and ("+") not ("-"). Ex perl + faq -cgi :
+Documents with faq, eventually perl and not cgi.
+
+=item *
+
+Client Perl or PHP
+
+=item *
+
+Can browse site by directory / rubrique.
+
+=item *
+
+Search for different criteria: news, last modified date, language, URL / site.
+
+=back
+
+=item *
+
+Full text indexing
+
+=item *
+
+Different weights for title, keywords, description and rest of page HTML read can be given in configuration
+
+=item *
+
+Herite from features of LWP suite:
+
+=over
+
+=item *
+
+Support protocol HTTP://,FTP://, FILE:// (Can do indexation of filesystem without talk to Web Server)
+
+=item *
+
+Full support of standard robots exclusion (robots.txt). Identification with
+CircaIndexer/0.1, mail alian@alianwebserver.com. Delay requests to
+the same server for 8 secondes. "It's not a bug, it's a feature!" Basic
+rule for HTTP serveur load.
+
+=item *
+
+Support proxy HTTP.
+
+=back
+
+=item *
+
+Make index in MySQL
+
+=item *
+
+Read HTML and full text plain
+
+=item *
+
+Several kinds of indexing : full, incremental, only on a particular server.
+
+=item *
+
+Documents not updated are not reindexed.
+
+=item *
+
+All requests for a file are made first with a head http request, for information
+such as validate, last update, size, etc.Size of documents read can be
+restricted (Ex: don't get all documents > 5 MB). For use with low-bandwidth
+connections, or computers which do not have much memory.
+
+=item *
+
+HTML template can be easily customized for your needs.
+
+=item *
+
+Admin functions available by browser interface or command-line.
+
+=item *
+
+Index the different links found in a CGI (all after name_of_file?)
+
+=back
+
 =head2 How it's work ?
 
 Circa parse html document. convert it to text. It count all
@@ -826,8 +892,6 @@ it read title, keywords, description and add a weight to
 all word found.
 
 Example:
-A config:
-
  my %ConfigMoteur=(
   'author'              => 'circa@alianwebserver.com', # Responsable du moteur
   'temporate'           => 1,  # Temporise les requetes sur le serveur de 8s.
@@ -841,8 +905,6 @@ A config:
   'indexCgi'            => 0,  # Index lien des CGI (ex: ?nom=toto&riri=eieiei)
   );
 
-A html document:
-
  <html>
  <head>
  <meta name="KeyWords"
@@ -871,13 +933,17 @@ relation.
 After page is read, it's look into html link. And so on. At each time, the level
 grow to one. So if < to $Config{'niveau_max'}, url is added.
 
+=head1 VERSION
+
+$Revision: 1.24 $
+
 =head1 Class Interface
 
 =head2 Constructors and Instance Methods
 
 =over
 
-=item B<new> I<PARAMHASH>
+=item new    [PARAMHASH]
 
 You can use the following keys in PARAMHASH:
 
@@ -928,20 +994,20 @@ Default 0, follow of not links of CGI (ex: ?nom=toto&riri=eieiei)
 
 =back
 
-=item B<size_max> I<size>
+=item size_max($size)
 
 Get or set size max of file read by indexer (For avoid memory pb).
 
-=item B<host_indexed> I<host>
+=item host_indexed($host)
 
 Get or set the host indexed.
 
-=item B<set_host_indexed> I<url>
+=item set_host_indexed($url)
 
 Set base directory with $url. It's used for restrict access
 only to files found on sub-directory on this serveur.
 
-=item B<proxy> I<adresse proxy>
+=item proxy($adr_proxy)
 
 Get or set proxy for LWP::Robot or LWP::Agent
 
@@ -953,14 +1019,20 @@ Ex: $circa->proxy('http://proxy.sn.no:8001/');
 
 =over
 
-=item B<addSite> I<ref_hash>
+=item addSite($url,$email,$titre,$categorieAuto,$cgi,$rep,$file);
 
-I<ref_hash> can have these keys: url, email, title, categorieAuto,
-cgi, rep, file
+Ajoute le site d'url $url, responsable d'adresse mail $email  la bd de Circa
+Retourne l'id du compte cree
 
-Create account with first url I<url>. Return id of account created
+Create account for url $url. Return id of account created.
 
-=item B<parse_new_url> I<id account>
+
+=item addLocalSite($url,$email,$titre,$local_url,$path,
+                   $urlRacine,$categorieAuto,$cgi,$rep,$file);
+
+Add a local $url
+
+=item parse_new_url($idp)
 
 Parse les pages qui viennent d'tre ajoute. Le programme va analyser toutes
 les pages dont la colonne 'parse' est gale  0.
@@ -968,10 +1040,10 @@ les pages dont la colonne 'parse' est gale  0.
 Retourne le nombre de pages analyses, le nombre de page ajoutes, le
 nombre de mots indexs.
 
-=item B<update> I<nb days, id account>
+=item update($xj,[$idp])
 
-Update url not visited since I<nb days> for account I<id account>.
-If idp is not given, 1 will be used. Url never parsed will be indexed.
+Update url not visited since $xj days for account $idp. If idp is not
+given, 1 will be used. Url never parsed will be indexed.
 
 Return ($nb,$nbAjout,$nbWords,$nbWordsGood)
 
@@ -997,7 +1069,7 @@ $nbWordsGood: Number of word added
 
 =cut
 
-=item B<create_table_circa>
+=item create_table_circa
 
 Create tables needed by Circa - Cree les tables necessaires  Circa:
 
@@ -1027,62 +1099,61 @@ inscription : Inscriptions temporaires
 
 =cut
 
-=item B<drop_table_circa>
+=item drop_table_circa
 
 Drop all table in Circa ! Be careful ! - Detruit touted les tables de Circa
 
 =cut
 
-=item B<drop_table_circa_id> I<id account>
+=item drop_table_circa_id($id)
 
-Drop table for account I<id account>
+Detruit les tables de Circa pour l'utilisateur $id
 
 =cut
 
-=item B<create_table_circa_id> I<id account>
+=item create_table_circa_id($id)
 
-Create tables needed by Circa for account I<id account>
+Create tables needed by Circa for instance $id:
 
 =over
 
-=item categorie
+=item *
 
-Catgories de sites
+categorie   : Catgories de sites
 
-=item links
+=item *
 
-Liste d'url
+links       : Liste d'url
 
-=item relations
+=item *
 
-Liste des mots / id site indexes
+relations   : Liste des mots / id site indexes
 
-=item stats
+=item *
 
-Liste des requetes
+stats   : Liste des requetes
 
 =back
 
-=item B<export> I<[mysqldump], [directory of export]>
+=item export([$mysqldump], [$path])
 
-Export data from Mysql in I<directory of export>/circa.sql with
-I<mysqldump>.
+Export data from Mysql in $path/circa.sql
 
-I<mysqldump>: path of bin of mysqldump. If not given, search in 
-/usr/bin/mysqldump, /usr/local/bin/mysqldump, /opt/bin/mysqldump.
+$mysqldump: path of bin of mysqldump. If not given, search in /usr/bin/mysqldump,
+/usr/local/bin/mysqldump, /opt/bin/mysqldump.
 
-<directory of export>: path of directory where circa.sql will be created.
-If not given, create it in $CircaConf::export, else in /tmp directory.
+$path: path of directory where circa.sql will be created. If not given,
+create it in current directory.
 
-=item B<import_data> I<[path_of_bin_mysql], [path_of_circa_file]>
+=item import_data([$mysql], [$path])
 
 Import data in Mysql from circa.sql
 
-I<path_of_bin_mysql> : path to reach bin of mysql. If not given, search in 
-/usr/bin/mysql, /usr/local/bin/mysql, /opt/bin/mysql, ENV{PATH}
+$mysql : path of bin of mysql. If not given, search in /usr/bin/mysql,
+/usr/local/bin/mysql, /opt/bin/mysql
 
-I<path_of_circa_file> : path of directory where circa.sql will be read.
-If not given, read it from $CircaConf::export, else /tmp directory.
+$path: path of directory where circa.sql will be read. If not given,
+read it from current directory.
 
 =back
 
@@ -1090,53 +1161,54 @@ If not given, read it from $CircaConf::export, else /tmp directory.
 
 =over
 
-=item B<admin_compte> I<id account>
+=item admin_compte($compte)
 
-Return hash with some informations account I<id account>
-Keys are:
+Return list about account $compte
+
+Retourne une liste d'elements se rapportant au compte $compte
 
 =over
 
-=item responsable
+=item *
 
-Email address given with account creation
+$responsable  : Adresse mail du responsable
 
-=item titre
+=item *
 
-Title given with account creation
+$titre    : Titre du site pour ce compte
 
-=item nb_links
+=item *
 
-Number of url for this account
+$nb_page  : Number of url added to Circa - Nombre de page pour ce site
 
-=item nb_words
+=item *
 
-Number of world stored
+$nb_words : Number of world added to Circa - Nombre de mots indexs
 
-=item last_index
+=item *
 
-Date of last index process
+$last_index  : Date of last indexation. Date de la dernire indexation
 
-=item nb_request
+=item *
 
-Number of request asked
+$nb_requetes  : Number of request aked - Nombre de requetes effectues sur ce site
 
-=item racine
+=item *
 
-Url given with account creation
+$racine  : First page added - 1ere page inscrite
 
 =back
 
-=item B<most_popular_word> I<nb item to display, id account>
+=item most_popular_word($max,$id)
 
 Retourne la reference vers un hash representant la liste
 des $max mots les plus prsents dans la base de reponsable $id
 
-=item B<stat_request> I<id account>
+=item stat_request($id)
 
 Return some statistics about request make on Circa
 
-=item B<inscription> I<email, url, titre>
+=item inscription($email,$url,$titre)
 
 Inscrit un site dans une table temporaire
 
@@ -1146,45 +1218,38 @@ Inscrit un site dans une table temporaire
 
 =over
 
-=item B<header_compte> I<CGI object, id account, url of script>
+=item header_compte
 
 Function use with CGI admin_compte.cgi. Display list of features of 
-admin_compte.cgi for this account
+admin_compte.cgi with this account
 
-=item B<get_liste_liens> I<id account>
+=item get_liste_liens($id)
 
-Return a html select buffer with list of url for account I<id account>
+Rend un buffer contenant une balise select initialise avec les donnes
+de la table links responsable $id
 
-=item B<get_liste_liens_a_valider> I<id account>,I<CGI object>
+=item get_liste_liens_a_valider($id)
 
-Return a html select buffer with link to valid for account I<id account>
+Rend un buffer contenant une balise select initialise avec les donnes
+de la table links responsable $id liens non valides
 
-=item B<get_liste_site> I<cgi object>
+=item get_liste_site
 
-Return a html select buffer with list of account
+Rend un buffer contenant une balise select initialise avec les donnes
+de la table responsable
 
-=item B<get_liste_langues> I<id account, default value, CGI object>
+=item get_liste_langues
 
-Return a html select buffer with distinct known languages found at index time
+Rend un buffer contenant une balise select initialise avec les donnes
+de la table responsable
 
-=item B<get_liste_mot> I<id account>, I<id url>
+=item get_liste_mot
 
-Return a html buffer with words found at index time for url I<id url>.
+Rend un buffer contenant une balise select initialise avec les donnes
+de la table responsable
 
 =back
 
-=head1 SEE ALSO
-
-L<Search::Circa>, Root class for circa
-
-L<Search::Circa::Parser>, Manage Parser of Indexer
-
-L<circa_admin>, command line to use indexer
-
-=head1 VERSION
-
-$Revision: 1.39 $
-
 =head1 AUTHOR
 
 Alain BARBET alian@alianwebserver.com
