@@ -4,25 +4,55 @@ package Search::Circa::Search;
 # Copyright 2000 A.Barbet alian@alianwebserver.com.  All rights reserved.
 
 # $Log: Search.pm,v $
-# Revision 1.21  2002/12/29 03:18:37  alian
-# Update POD documentation
+# Revision 1.15  2001/08/29 16:25:02  alian
+# - Remove get_liste_categorie_fils() routine (move in Categorie)
+# - Update POD documentation for new namespace
 #
-# Revision 1.20  2002/12/28 12:37:47  alian
-# - Ajout phase privilegiant le et (+nb mots*100 au score si tous les mots trouves dans le doc)
-# - Affichage que de 20 liens suivants / precedant
+# Revision 1.14  2001/08/24 13:29:30  alian
+# - Renomme Circa::Search in Search::Circa::Search
 #
-# Revision 1.19  2002/12/27 12:54:48  alian
-# Use template from conf
+# Revision 1.13  2001/06/02 08:17:22  alian
+# - Correct a bug in + and - search
 #
-# Revision 1.18  2002/08/17 18:19:02  alian
-# - Minor changes to all code suite to tests
+# Revision 1.12  2001/05/28 23:58:24  alian
+# - Add link on name of categorie
 #
-# Revision 1.17  2001/11/19 11:38:23  alian
-# - Correction d'un bug sur l'analyse des mots and (cas ou + sur le premier
-# mot) ainsi +mot1 +mot2 = +mot2 +mot1
+# Revision 1.11  2001/05/23 00:05:42  alian
+# - Correct an another  bug in categories_in_categorie
+#
+# Revision 1.10  2001/05/22 23:26:45  alian
+# - Correct a bug in categories_in_categorie
+#
+# Revision 1.9  2001/05/21 22:47:40  alian
+# - Remove some method use in Search and Indexer and build 
+# a father class : Circa.pm
+#
+# Revision 1.8  2001/05/14 14:55:17  alian
+# - Move POD documentation at end of file
+# - Update some routine (trouble with CGI)
+# - Update getMasque routine. Return undef if no masque
+#
+# Revision 1.7  2001/04/15 13:35:46  alian
+# - Remove use CGI module, use as parameters
+#
+# Revision 1.6  2001/02/05 00:11:29  alian
+# - Add pod documentation
+# - Display sites in categories by page (as in search)
+# - Add request to stats table
+#
+# Revision 1.5  2000/11/23 22:53:57  Administrateur
+# Add use of template as parameter
+#
+# Revision 1.4  2000/09/28 15:56:32  Administrateur
+# - Update SQL search method
+# - Add + and - to syntax of word search
+# - Add search in one categorie only
+#
+# Revision 1.3  2000/09/25 21:39:44  Administrateur
+# - Update possibilities to browse several site on a same database
+# - Update navigation by category
+# - Use new MCD
 #
-# Revision 1.16  2001/10/14 17:17:32  alian
-# - Suppression d'une trace oubliee sur les mots avec and
 
 use DBI;
 use Search::Circa;
@@ -34,7 +64,15 @@ require Exporter;
 
 @ISA = qw(Exporter Search::Circa);
 @EXPORT = qw();
-$VERSION = ('$Revision: 1.21 $ ' =~ /(\d+\.\d+)/)[0];
+$VERSION = ('$Revision: 1.15 $ ' =~ /(\d+\.\d+)/)[0];
+
+# -------------------
+# Template par defaut
+my $templateS='"<p>$indiceG - <a href=\"$url\"> $titre </a> $description <br>
+    <font class=\"small\"><b>Url:</b> $url <b>Facteur:</b> $facteur
+    <b>Last update:</b> $last_update </font></p>\n\n"';
+my $templateC='"<p><a href=\"$links\">$nom_complet</a><br></p>\n"';
+# -------------------
 
 #------------------------------------------------------------------------------
 # new
@@ -57,13 +95,11 @@ sub search
   {
   my ($this,$template,$mots,$first,$idc,$langue,$Url,
       $create,$update,$categorie,$cgi)=@_;
-  $this->trace(5);
   $this->dbh->do("insert into ".$this->pre_tbl.$idc."stats ".
 			"(requete,quand) values('$mots',now())");
-  if (!$template) {$template=$CircaConf::templateS;}
+  if (!$template) {$template=$templateS;}
   my ($indice,$i,$tab,$nbPage,$links,$resultat,@ind_and,@ind_not,@mots_tmp)
     = (0,0);
-  my %rrr; $tab=\%rrr;
   $mots=~s/\'/ /g;
   $mots=~s/(\w)-(\w)/$1 + $2/;
   my @mots = split(/\s/,$mots);
@@ -72,25 +108,18 @@ sub search
     {
     if    ($_ eq '+') {push(@ind_and,$i);} # Reperage mots 'and'
     elsif ($_ eq '-') {push(@ind_not,$i);} # Reperage mots 'not'
-    else {push(@mots_tmp,$_); $i++;}
+    else {push(@mots_tmp,$_);}
+    $i++;
     }
   # Recherche SQL
   $tab=$this->search_word($tab,join("','",@mots_tmp),$idc,
-			  $langue,$Url,$create,$update,$categorie) ||
-			    return undef;
-
-  # On ajoute 100 au urls qui contiennent tous les mots demandes si nb mots > 1
-  if ($#mots>0) {
-    foreach my $url (keys %$tab) {
-      $$tab{$url}[2]+=(100*($#mots+1)) if ($#mots+1 == scalar @{$$tab{$url}[5]});
-    }
-  }
-
+			  $langue,$Url,$create,$update,$categorie);
   # On supprime tout ceux qui ne repondent pas aux criteres and si present
-  foreach my $ind (@ind_and) {
+  foreach my $ind (@ind_and) {   print "mp $ind : ",$mots_tmp[$ind],"\n";
     foreach my $url (keys %$tab) {
+   
       delete $$tab{$url} if 
-	(!$this->appartient($mots_tmp[$ind],@{$$tab{$url}[5]}));} }
+	(!$this->appartient($mots_tmp[$ind],@{$$tab{$url}[5]}));}}
 
   # On supprime tout ceux qui ne repondent pas aux criteres not si present
   foreach my $ind (@ind_not) {
@@ -107,36 +136,36 @@ sub search
 	       || $this->{nbResultPerPage};}
   else {$nbResultPerPage= $this->{nbResultPerPage};}
   my $lasto = $first + $nbResultPerPage;
-  foreach my $url (@key) {
-    my ($titre,$description,$facteur,$langue,$last_update)=@{$$tab{$url}};
-    my $indiceG=$indice+1;
-    if (($indice>=$first)&&($indice<$lasto)) {
+  foreach my $url (@key)
+     {
+     my ($titre,$description,$facteur,$langue,$last_update)=@{$$tab{$url}};
+     my $indiceG=$indice+1;
+     if (($indice>=$first)&&($indice<$lasto))
+      {
       if ($template) {$resultat.= eval $template;}
       else {$resultat.=$url."\t".$titre."\n";}
-    }
-    # Constitution des liens suivants / precedents
-    if (!($indice%$nbResultPerPage)) {
-      $nbPage++;
-      if ($indice < ($first+($nbResultPerPage*10))
-	  and $indice > ($first-($nbResultPerPage*10))) {
-	if ($indice==$first) {$links.="$nbPage- ";}
-	elsif ($ENV{"SCRIPT_NAME"}) 
-	  {$links.='<a class="liens_suivant" href="'.
-	     $this->get_link($indice,$cgi).'">'.$nbPage.'</a>- '."\n";}
       }
-    }
+     # Constitution des liens suivants / precedents
+    if (!($indice%$nbResultPerPage))
+      {
+      $nbPage++;
+      if ($indice==$first) {$links.="$nbPage- ";}
+      elsif ($ENV{"SCRIPT_NAME"}) 
+	{$links.='<a class="liens_suivant" href="'.
+	   $this->get_link($indice,$cgi).'">'.$nbPage.'</a>- '."\n";}
+      }
     $indice++;
-  }
+    }
   if (@key==0) {$resultat="<p>Aucun document trouv.</p>";}
   return ($resultat,$links,$indice);
-}
+  }
 
 #------------------------------------------------------------------------------
 # search_word
 #------------------------------------------------------------------------------
-sub search_word  {
+sub search_word
+  {
   my ($self,$tab,$word,$idc,$langue,$Url,$create,$update,$categorie)=@_;
-  $self->trace(5);
   # Restriction diverses
   # Lang
   if ($langue) {$langue=" and langue='$langue' ";} else {$langue= ' ';}
@@ -169,29 +198,22 @@ sub search_word  {
     and   r.mot in ('$word')
     $langue $Url $create $update $categorie
     order   by facteur desc";
-  $self->trace(3,"Search::Circa::Search::search_word $requete");
+
   my $sth = $self->dbh->prepare($requete);
   #print "requete:$requete\n";
-  if ($sth->execute()) {
-    my $nb=0;
-    while (my ($facteur,$url,$titre,$description,$langue,$last_update,$mot)
-	   =$sth->fetchrow_array) {
-      $$tab{$url}[0]=$titre;
-      $$tab{$url}[1]=$description;
-      $$tab{$url}[2]+=$facteur;
-      $$tab{$url}[3]=$langue;
-      $$tab{$url}[4]=$last_update;
-      push(@{$$tab{$url}[5]},$mot);
-      $nb++;
+  $sth->execute() || print "Erreur $requete:$DBI::errstr\n";
+  while (my ($facteur,$url,$titre,$description,$langue,$last_update,$mot)
+	 =$sth->fetchrow_array)
+    {
+    $$tab{$url}[0]=$titre;
+    $$tab{$url}[1]=$description;
+    $$tab{$url}[2]+=$facteur;
+    $$tab{$url}[3]=$langue;
+    $$tab{$url}[4]=$last_update;
+    push(@{$$tab{$url}[5]},$mot);
     }
-    $self->trace(3,"Search::Circa::Search::search_word $nb results");
-    return $tab;
-  }  else {
-    $self->trace(1,
-		 "Circa::Search->search word Erreur $requete:$DBI::errstr\n");
-    return undef;
+  return $tab;
   }
-}
 
 #------------------------------------------------------------------------------
 # get_link
@@ -360,16 +382,16 @@ Search::Circa::Search - Search interface on Circa, a www search engine running w
 
  use Search::Circa::Search;
  my $search = new Search::Circa::Search;
- 
+
  # Connection  MySQL
- die "Erreur  la connection MySQL:$DBI::errstr\n"
-   if (!$search->connect);
- 
+ if (!$search->connect("aliansql","pass","my_database","localhost"))
+  {die "Erreur  la connection MySQL:$DBI::errstr\n";}
+
  # Affichage d'un formulaire minimum
  print   header,
    $search->start_classic_html,
    $search->default_form;
- 
+
  # Interrogation du moteur
  # Sites trouves, liens pages suivantes, nb pages trouvees
  my ($resultat,$links,$indice) = $search->search('informatique internet',0,1);
@@ -378,7 +400,11 @@ Search::Circa::Search - Search interface on Circa, a www search engine running w
 =head1 DESCRIPTION
 
 This is Search::Circa::Search, a module who provide functions to
-perform search on Circa database
+perform search on Circa, a www search engine running with
+Mysql. Circa is for your Web site, or for a list of sites.
+It indexes like Altavista does. It can read, add and
+parse all url's found in a page. It add url and word
+to MySQL for use it at search.
 
 Notes:
 
@@ -397,6 +423,10 @@ Search are case unsensitive (mmmh what my english ? ;-)
 Circa::Search work with Circa::Indexer result. Circa::Search is a Perl 
 interface, but it's exist on this package a PHP client too.
 
+=head1 VERSION
+
+$Revision: 1.15 $
+
 =head1 Class Interface
 
 =head2 Constructors and Instance Methods
@@ -655,16 +685,6 @@ Retourne le nom du site dans la table responsable correspondant  l'id $id
 
 =back
 
-=head1 VERSION
-
-$Revision: 1.21 $
-
-=head1 SEE ALSO
-
-L<Search::Circa>, Root class for circa
-
-L<circa_search>, command line script to perform search
-
 =head1 AUTHOR
 
 Alain BARBET alian@alianwebserver.com
