@@ -1,8 +1,47 @@
 package Search::Circa::Url;
 
-# module Circa::Url : Manage url of Circa. See Search::Circa
+# module Circa::Url : See Circa::Indexer
 # Copyright 2000 A.Barbet alian@alianwebserver.com.  All rights reserved.
 
+# $Log: Url.pm,v $
+# Revision 1.11  2001/08/26 23:08:32  alian
+# - Update POD documentation
+#
+# Revision 1.10  2001/08/24 13:37:56  alian
+# - Ajout du prefix Search:: devant chacun des modules
+#
+# Revision 1.9  2001/08/01 19:41:44  alian
+# - Remove 2 warnings in update method
+#
+# Revision 1.8  2001/05/22 10:24:55  alian
+# - Update for new architecture
+#
+# Revision 1.7  2001/05/21 22:34:27  alian
+# - Add load method
+#
+# Revision 1.6  2001/05/20 11:24:00  alian
+# - Change add and update method: use a hash as parameter
+# - Add liens method
+# - Update POD documentation
+#
+# Revision 1.5  2001/05/15 22:58:52  alian
+# - Add NeedParser and NeedUpdate
+#
+# Revision 1.4  2001/05/15 22:12:41  alian
+# - Ajout fonctionnalit valid_all_url et delete_all_non_valid
+#
+# Revision 1.3  2001/05/15 21:35:10  alian
+# - Correct error in non_valide
+#
+# Revision 1.2  2001/05/14 23:23:28  alian
+# - Update POD documentation
+# - Add non_valide method
+#
+# Revision 1.1  2001/05/14 14:59:02  alian
+# - Code retir de Indexer.pm
+#
+#
+
 use strict;
 use DBI;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
@@ -10,7 +49,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw();
-$VERSION = ('$Revision: 1.19 $ ' =~ /(\d+\.\d+)/)[0];
+$VERSION = ('$Revision: 1.11 $ ' =~ /(\d+\.\d+)/)[0];
 
 
 #------------------------------------------------------------------------------
@@ -30,92 +69,66 @@ sub new
 #------------------------------------------------------------------------------
 # add
 #------------------------------------------------------------------------------
-sub add  {
-  my ($self,$idMan,%url)=@_;
-  my $id;
-  $idMan=1 if (!$idMan);
-  $url{niveau}=0 if (!$url{niveau});
-  $url{titre}=~s/([^\\])'/$1\\'/g if ($url{titre});
-  $url{description}=~s/([^\\])'/$1\\'/g if ($url{description});
-  chop ($url{url}) if ($url{url}=~/\/$/);
-  my $requete = "insert into ".$self->{INDEXER}->pre_tbl.$idMan."links set ";
-  $requete.= "url           = '$url{url}'"          if ($url{url});
-  $requete.= ",local_url     = '$url{urllocal}'"    if ($url{urllocal});
-  $requete.= ",titre         = '$url{titre}'"       if ($url{titre});
-  $requete.= ",description   = '$url{description}'" if ($url{description});
-  $requete.= ",langue        = '$url{langue}'"      if ($url{langue});
-  $requete.= ",categorie     = $url{categorie}"     if ($url{categorie});
-  $requete.= ",parse         = '$url{parse}'"       if ($url{parse});
-  $requete.= ",valide        = $url{valide}"        if ($url{valide});
-  $requete.= ",niveau        = $url{niveau}"        if ($url{niveau});
-  $requete.= ",last_check    = $url{last_check}"    if ($url{last_check});
-  $requete.= ",last_update   = '$url{last_update}'" if ($url{last_update});
-  $requete.= ",browse_categorie ='$url{browse_categorie}'"
+sub add
+  {
+    my ($self,$idMan,%url)=@_;
+    $idMan=1 if (!$idMan);
+    $url{niveau}=0 if (!$url{niveau});
+    chop ($url{url}) if ($url{url}=~/\/$/);
+    my $requete = "insert into ".$self->{INDEXER}->pre_tbl.$idMan."links set ";
+    $requete.= "url           = '$url{url}'"         if ($url{url});
+    $requete.= ",local_url     = '$url{urllocal}'"    if ($url{urllocal});
+    $requete.= ",titre         = '$url{titre}'"       if ($url{titre});
+    $requete.= ",description   = '$url{description}'" if ($url{description});
+    $requete.= ",langue        = '$url{langue}'"      if ($url{langue});
+    $requete.= ",categorie     = $url{categorie}"     if ($url{categorie});
+    $requete.= ",parse         = '$url{parse}'"       if ($url{parse});
+    $requete.= ",valide        = $url{valide}"        if ($url{valide});
+    $requete.= ",niveau        = $url{niveau}"        if ($url{niveau});
+    $requete.= ",last_check    = $url{last_check}"  if ($url{last_check});
+    $requete.= ",last_update   = '$url{last_update}'"  if ($url{last_update});
+    $requete.= ",browse_categorie ='$url{browse_categorie}'" 
       if ($url{browse_categorie});
-  #print $requete,"<br>\n";
-  $self->{INDEXER}->trace(4, $requete."\n");
-  my $sth = $self->{DBH}->prepare($requete);
-  if ($sth->execute) {
-      $sth->finish;
-      $id = $sth->{'mysql_insertid'};
-    }
-  else {
-    $self->{INDEXER}->trace(2, "Circa::Url->add $requete $DBI::errstr\n");
-    return undef;
+    #print $requete,"<br>\n";
+    $self->{DBH}->do($requete) || return 0; 
+    #print "Add $url<br>\n";
+    if ($DBI::errstr) {return 0;}
+    else { return 1;}
   }
-  return $id;
-}
 
 #------------------------------------------------------------------------------
 # update
 #------------------------------------------------------------------------------
-sub update  {
+sub update
+  {
   my ($self,$compte,%url)=@_;
-  return undef unless ($url{id});
-  if ($url{titre}) {
-    $url{titre}=~s/'/\\'/g;
-    $url{titre}=~s/\\\\'/\\'/g;
-  }
-  if ($url{description}) {
-    $url{description}=~s/'/\\'/g;
-    $url{description}=~s/\\\\'/\\'/g;
-  }
+  $url{'titre'}=~s/'/\\'/g if ($url{'titre'});
+  $url{'description'}=~s/'/\\'/g if ($url{'description'});
   my $requete =
-    "update ".$self->{INDEXER}->pre_tbl.$compte."links set \n";
-#  $requete.= "\n\turl    = '$url{url}',"         if ($url{url});
-  $requete.= "\n\tlocal_url  = '$url{urllocal}',"    if ($url{urllocal});
-  $requete.= "\n\ttitre     = '$url{titre}',"       if ($url{titre});
-  $requete.= "\n\tdescription ='$url{description}'," 
-    if ($url{description});
-  $requete.= "\n\tlangue   = '$url{langue}',"      if ($url{langue});
-  $requete.= "\n\tcategorie  = $url{categorie},"     if ($url{categorie});
-  $requete.= "\n\tparse    = '$url{parse}',"       if ($url{parse});
-  $requete.= "\n\tvalide     = $url{valide},"        if ($url{valide});
-  $requete.= "\n\tniveau     = $url{niveau},"        if ($url{niveau});
-  if ($url{last_check})
-    {
-	if ($url{last_check} eq 'NOW()')
-	  {$requete.= "\n\tlast_check  = NOW(),";}
-	else { $requete.= "\n\tlast_check  = '$url{last_check}',"; }
-    }
-  $requete.= "\n\tlast_update      = '$url{last_update}',"  
-    if ($url{last_update});
-  $requete.= "\n\tbrowse_categorie ='$url{browse_categorie}'," 
+    "update ".$self->{INDEXER}->pre_tbl.$compte."links set ";
+  $requete.= "url              = '$url{url}',"         if ($url{url});
+  $requete.= "local_url        = '$url{urllocal}',"    if ($url{urllocal});
+  $requete.= "titre            = '$url{titre}',"       if ($url{titre});
+  $requete.= "description      = '$url{description}'," if ($url{description});
+  $requete.= "langue           = '$url{langue}',"      if ($url{langue});
+  $requete.= "categorie        = $url{categorie},"     if ($url{categorie});
+  $requete.= "parse            = '$url{parse}',"       if ($url{parse});
+  $requete.= "valide           = $url{valide},"        if ($url{valide});
+  $requete.= "niveau           = $url{niveau},"        if ($url{niveau});
+  $requete.= "last_check       = $url{last_check},"  if ($url{last_check});
+  $requete.= "last_update      = '$url{last_update}'"  if ($url{last_update});
+  $requete.= "browse_categorie ='$url{browse_categorie}'," 
     if ($url{browse_categorie});
-  if ($requete=~/,$/) { chop($requete); }
   $requete.="  where id=$url{id}"; 
-#  print $requete;
-
-  $self->{INDEXER}->trace(4, $requete."\n");
-  my $r = $self->{DBH}->do($requete) || return undef;
-#  print "$requete $DBI::errstr\n" if (!$r or $r eq '0E0');
-  return ((!$r or $r eq '0E0') ? 0 : 1);
-}
+  #print $requete;
+  $self->{DBH}->do($requete) || print "Erreur: $requete $DBI::errstr<br>\n";
+  }
 
 #------------------------------------------------------------------------------
 # load
 #------------------------------------------------------------------------------
-sub load  {
+sub load
+  {
   my ($self,$compte,$id)=@_;
   my @l = $self->{INDEXER}->fetch_first
     ("select url,local_url,titre,description,
@@ -123,8 +136,6 @@ sub load  {
              last_check,last_update,browse_categorie
     from ".$self->{INDEXER}->pre_tbl.$compte."links
     where id=".$id);
- # print "load $id:", join(' ',@l),"\n";
-  return 0 if (!@l);
   my %tab=
     ( url              => $l[0],
       local_url        => $l[1],
@@ -140,67 +151,70 @@ sub load  {
       browse_categorie => $l[11],
       );
   return \%tab;
-}
+  }
 
 #------------------------------------------------------------------------------
 # delete
 #------------------------------------------------------------------------------
-sub delete  {
-  my ($this,$compte,$id_url)=@_;
-  $this->{DBH}->do
-    ("delete from ".$this->{INDEXER}->pre_tbl.$compte."relation".
-     "where id_site = $id_url");
-  my $r = $this->{DBH}->do("delete from ".$this->{INDEXER}->pre_tbl.$compte.
-			   "links where id = $id_url") || return 0;
-  return ((!$r or $r eq '0E0') ? 0 : 1);
+sub delete
+  {
+    my ($this,$compte,$id_url)=@_;
+    $this->{DBH}->do
+      ("delete from ".$this->{INDEXER}->pre_tbl.$compte."relation".
+               "where id_site = $id_url");
+    $this->{DBH}->do("delete from ".$this->{INDEXER}->pre_tbl.$compte."links ".
+		     "where id = $id_url");
   }
 
 #------------------------------------------------------------------------------
 # delete_all_non_valid
 #------------------------------------------------------------------------------
-sub delete_all_non_valid  {
-  my ($self,$id)=@_;
-  my $tt = 0;
-  my $tab = $self->a_valider($id) || return undef;
-  foreach (keys %$tab) {$tt += $self->delete($id,$_);}
-  return $tt;
-}
+sub delete_all_non_valid
+  {
+    my ($self,$id)=@_;
+    my $tab = $self->a_valider($id);
+    foreach (keys %$tab) {$self->delete($id,$_);}
+  }
 
 #------------------------------------------------------------------------------
 # valid_all_non_valid
 #------------------------------------------------------------------------------
-sub valid_all_non_valid  {
-  my ($self,$id)=@_;
-  my $tt = 0;
-  my $tab = $self->a_valider($id) || return undef;
-  foreach (keys %$tab) {$tt+= $self->valide($id,$_);}
-  return $tt;
-}
+sub valid_all_non_valid
+  {
+    my ($self,$id)=@_;
+    my $tab = $self->a_valider($id);
+    foreach (keys %$tab) {$self->valide($id,$_);}
+  }
 
 #------------------------------------------------------------------------------
 # need_parser
 #------------------------------------------------------------------------------
-sub need_parser {
-  my ($self,$idp)=@_;
-  my %tab;
-  my $requete="select id,url,local_url,niveau,categorie ".
-    "from ".$self->{INDEXER}->pre_tbl.$idp."links ".
-    "where parse='0' and valide=1 ".
-    "order by niveau,id";
-  my $sth = $self->{DBH}->prepare($requete);
-  if ($sth->execute()) {
-    while (my @row=$sth->fetchrow_array) {
-      my $id = shift @row; 
-      $tab{$id}[0]=$row[0]; # url
-      $tab{$id}[1]=$row[1]; # local_url
-      $tab{$id}[2]=$row[2]; # niveau
-      $tab{$id}[3]=$row[3]; # categorie
-    }
+sub need_parser
+  { 
+    my ($self,$idp)=@_;
+    my %tab;
+    my $requete="select id,url,local_url,niveau,categorie,".
+                       "UNIX_TIMESTAMP(last_update) ".
+                 "from ".$self->{INDEXER}->pre_tbl.$idp."links ".
+                 "where parse='0' and valide=1 ".
+                 "order by id";
+    my $sth = $self->{DBH}->prepare($requete);
+    if ($sth->execute())
+      {
+	while (my @row=$sth->fetchrow_array)
+	  { 
+	    my $id = shift @row; 
+	    $tab{$id}[0]=$row[0]; # url
+	    $tab{$id}[1]=$row[1]; # local_url
+	    $tab{$id}[2]=$row[2]; # niveau
+	    $tab{$id}[3]=$row[3]; # categorie
+	    $tab{$id}[4]=$row[4]; # last_update	    
+	  }
+      }
+    else {print "\nDid you call create before ?\n";}
+    $sth->finish;
+    return \%tab;
   }
-  else {print "\nDid you call create before ?\n";}
-  $sth->finish;
-  return \%tab;
-}
 
 #------------------------------------------------------------------------------
 # liens
@@ -234,7 +248,7 @@ sub need_update
                         UNIX_TIMESTAMP(last_update)
                  from ".$self->{INDEXER}->pre_tbl.$idp."links
                  where TO_DAYS(NOW()) >= (TO_DAYS(last_check) + $xj)
-                 and valide=1 order by niveau,last_update";
+                 and valide=1 order by url";
     my $sth = $self->{DBH}->prepare($requete);
     if ($sth->execute())
       {
@@ -263,7 +277,7 @@ sub a_valider
     my $sth = $self->{DBH}->prepare("select id,url from ".
 				    $self->{INDEXER}->pre_tbl.$id."links ".
 				    "where valide=0");
-    $sth->execute() || return undef;
+    $sth->execute() || print &header,$DBI::errstr,"<br>\n";
     while (my @row=$sth->fetchrow_array)
       {
 	$self->{INDEXER}->set_host_indexed($row[1]);
@@ -278,23 +292,21 @@ sub a_valider
 #------------------------------------------------------------------------------
 # valide
 #------------------------------------------------------------------------------
-sub valide  {
+sub valide
+  {
   my ($this,$compte,$id_url)=@_;
-  my $r=$this->{DBH}->do("update ".$this->{INDEXER}->pre_tbl.$compte."links ".
-			 "set valide=1,parse='0' where id = $id_url") 
-    || return 0;
-  return ((!$r or $r eq '0E0') ? 0 : 1);
+  $this->{DBH}->do("update ".$this->{INDEXER}->pre_tbl.$compte."links ".
+		   "set valide=1,parse='0' where id = $id_url");
   }
 
 #------------------------------------------------------------------------------
 # non_valide
 #------------------------------------------------------------------------------
-sub non_valide  {
+sub non_valide
+  {
   my ($this,$compte,$id_url)=@_;
-  my $r=$this->{DBH}->do("update ".$this->{INDEXER}->pre_tbl.$compte."links".
-			 " set valide='0' where id=".$id_url) 
-    || return 0;
-  return ((!$r or $r eq '0E0') ? 0 : 1);
+  $this->{DBH}->do("update ".$this->{INDEXER}->pre_tbl.$compte."links".
+		   " set valide='0' where id=".$id_url);
   }
 
 #------------------------------------------------------------------------------
@@ -307,7 +319,7 @@ Search::Circa::Url - provide functions to manage url of Circa
 
 =head1 VERSION
 
-$Revision: 1.19 $
+$Revision: 1.11 $
 
 =head1 SYNOPSIS
 
@@ -397,27 +409,22 @@ Create a new Circa::Url object with indexer instance properties
 
 =item add($idMan,%url)
 
-Add url %url for account $idMan.
-If error (account undefined, no account, no url) return 0. You can ask
-$DBI::errstr to know why) or 1 if ok.
+Add url %url for account $idMan. If error return 0 (you can ask $DBI::errstr 
+to know why) or 1 if ok.
 
 =item load($compte,$id)
 
-Return reference to hash %url for id $id, account $compte.
-If error (id undefined, no id, no account) return 0. You can ask 
-$DBI::errstr to know why) or 1 if ok.
+Return reference to hash %url for id $id, account $compte
 
 =item update($compte,%url)
 
-Update url %url for account $compte.
-If error (id undefined, no id, no account) return 0. You can ask
-$DBI::errstr to know why) or 1 if ok. Field url can't be updated.
+Update url %url for account $compte
 
 =item delete($compte,$id_url)
 
-Delete url with id $id_url on account $compte (clean table links/releation)
-If error (id undefined, no id, no account) return 0. You can ask
-$DBI::errstr to know why)
+Delete url with id $id_url on account $compte
+
+Supprime le lien $id_url de la table $compte/relation et $compte/links
 
 =item delete_all_non_valid($id)
 
